Module api

Module api 

You’ll find in api all the different predefined endpoints organized by Postmark api sections.

In addition, some structures that are common to multiple endpoint API sections are included in here, specifically the definition of text and HTML based bodies.

Modules

bounce
You’ll find in bounce sending related endpoints.
email
You’ll find in email sending related endpoints.
message_streams
You’ll find in templates sending related endpoints.
server
You’ll find in email sending related endpoints.
templates
You’ll find in templates sending related endpoints.
webhooks
You’ll find in email sending related endpoints.

Structs

HtmlAndText

Enums

Body
The body of a email message